#
# spec file for package babeltrace2
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname  libbabeltrace2
%define sover   0
Name:           babeltrace2
Version:        2.1.0
Release:        bp160.1.4
Summary:        Common Trace Format Babel Tower
License:        GPL-2.0-only AND MIT
URL:            https://babeltrace.org/
Source:         https://efficios.com/files/babeltrace/%{name}-%{version}.tar.bz2
Source1:        https://efficios.com/files/babeltrace/%{name}-%{version}.tar.bz2.asc
Source2:        %{name}.keyring
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  python3-setuptools
BuildRequires:  swig
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libdw) >= 0.154
BuildRequires:  pkgconfig(libelf) >= 0.154
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(uuid)
ExclusiveArch:  %ix86 x86_64 aarch64 ppc64le ppc64 riscv64 s390x

%description
This project provides trace read and write libraries, as well as a
trace converter. A plugin can be created for any trace format to
allow its conversion to/from another trace format.

The main format expected to be converted to/from is the
Common Trace Format (CTF).

%package -n python3-%{name}
Summary:        Python Bindings for babeltrace2

%description -n python3-%{name}
This project provides trace read and write libraries, as well as a
trace converter. A plugin can be created for any trace format to
allow its conversion to/from another trace format.

Python Bindings for the babeltrace2 package.

%package -n %{name}-devel
Summary:        Common Trace Format Babel Tower
Requires:       %{name} = %{version}

%description -n %{name}-devel
This project provides trace read and write libraries, as well as a
trace converter. A plugin can be created for any trace format to
allow its conversion to/from another trace format.

The main format expected to be converted to/from is the
Common Trace Format (CTF).

%prep
%setup -q

%build
export PYTHON="python3"
export PYTHON_CONFIG="$PYTHON-config"
%configure \
  --disable-static            \
  --disable-Werror            \
  --docdir=%{_docdir}/%{name} \
  --enable-python-bindings
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
# Remove licences from doc.
rm %{buildroot}%{_docdir}/%{name}/LICENSE

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%doc %{_docdir}/%{name}/
%license LICENSE LICENSES/*
%{_bindir}/%{name}*
%{_libdir}/%{name}/
%{_libdir}/%{soname}*.so.%{sover}*
%{_mandir}/man1/*.1%{?ext_man}
%{_mandir}/man7/*.7%{?ext_man}

%files -n python3-%{name}
%{python3_sitearch}/bt2/
%{python3_sitearch}/bt2-*

%files -n %{name}-devel
%{_includedir}/%{name}/
%{_includedir}/%{name}-ctf-writer/
%{_libdir}/%{soname}*.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/pkgconfig/%{name}-ctf-writer.pc

%changelog
* Mon Mar 10 2025 Steve Kowalik <steven.kowalik@suse.com>
- Add BuildRequires on python3-setuptools, required for Python 3.12+.
* Thu Jan 30 2025 Ana Guerrero <ana.guerrero@suse.com>
- Update to 2.1.0
  Changelog changed to a verbose format, see ChangeLog file or
  https://babeltrace.org/docs/release-notes/babeltrace-2.1.0-release-notes.html
* Wed Jan 22 2025 Ana Guerrero <ana.guerrero@suse.com>
- Update to 2.0.6:
  * bt2: disable some warnings for `native_bt.c`
  * bt2: compile `native_bt.c` with `-Wno-undef`
  * Fix: src.ctf.lttng-live: expect NEW_STREAM/METADATA for inactive streams
  * Fix: `babeltrace2 convert`: don't consider the `--plugin-path` opt.
  * include/babeltrace2/plugin/plugin-dev.h: "define" -> "definition
  * Fix: doc: escape double quote in bt_p alias
  * Fix: bt2: pass _TraceClassConst to destruction listeners
  * fix: 'load_module()' deprecated in Python 3.12
  * tests: retry os.rename on PermissionError failure in lttng_live_server.py
  * doc: fix uptream -> upstream typos
  * fix: test_message_iterator.py hangs on Python 3.12
  * plugin-dev: mark symbols meant to be public with __attribute__((visibility("default")))
  * Silence -Wunused-but-set-variable error with clang
  * Fix: Windows DLL path lookup with Python >= 3.8
  * doc/man: make default values of boolean init. params. clearer
  * RFC: docs: fix: Match stated automake requirement
  * fix: make flake8 6.x happy
  * fix: running black on python 3.11
  * bt_query_executor_create_with_method_data(): fix docs note
  * Fix: ctf-writer: null dereference in bt_ctf_trace_common_add_stream_class
  * Update working version to Babeltrace v2.0.6
* Thu Aug  3 2023 Matthias Eliasson <elimat@opensuse.org>
- Update to 2.0.5:
  * bt2: honor build system compiler/linker preferences
  * Fix: clear_string_field(): set first character to 0
  * Fix: src.ctf.fs: Not resolving event common ctx
  * debug-info: fix -Wenum-int-mismatch problem in copy_field_class_content_internal
  * fix: pass exec-prefix to python bindings install
  * fix: document proper Bison version requirement
  * cli: use return value of g_string_free
  * babeltrace2-query(1): erroneous parameter used in example
  * Fix: tests: print real values in a fixed format
  * Fix: bt2: autodisc: remove thread error while inserting status in map
  * tests: src.ctf.fs: add test for metadata with invalid syntax
  * tests: shorten names of session-rotation trace
  * bt2: ignore -Wredundant-decls warning
  * ctf: fix -Wformat-overflow error in ctf-meta-resolve.cpp
  * ctf-writer: fix -Wformat-overflow errors in resolve.c
  * Fix: src.text.details: use write_uint_prop_value to handle unsigned values in write_int_range
  * Add dev-requirements.txt for pip
  * Fix: src.ctf.lttng-live: consider empty metadata packet as retry
  * Fix: ctf: wrongfully requiring CTF metadata signature for every section
  * Fix: src.ctf.lttng-live: session closed before any metadata is received
  * fix: obsolete warnings with autoconf >= 2.71
  * fix: explicitly disable '-Wsuggest-attribute=format'
  * fix: set stable branch in gitreview config
  * Fix: ctf-writer: list of reserved keywords
  * compiler warning cleanup: is_signed_type: compare -1 to 1
  * Update working version to Babeltrace 2.0.5
* Sun Apr 18 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 2.0.4:
  * Fix: macro name for "get supported mip versions method"
    attribute descriptor
  * Fix: disable deprecation warnings for SWIG generated code
  * Fix: sink.ctf.fs: fix logic of make_unique_stream_file_name
  * Fix: sink.ctf.fs: remove spurious directory level when using assume-single-trace
  * Fix: bt2: _trim_docstring(): docstring can have 0 or 1 line
  * Fix: `ctf` plugin: use element FC's alignment as array/seq. FC alignment
  * Fix: source.ctf.lttng-live: muxing failure on clear (unit conversion)
  * Fix: src.ctf.lttng-live: incomplete metadata packet is an error
  * Fix: source.ctf.lttng-live: muxing failure on clear
  * Fix: source.ctf.fs: 0-length packet index length causes SIGFPE
* Mon Aug 31 2020 Andreas Schwab <schwab@suse.de>
- Add riscv64 to ExclusiveArch
* Tue Aug 18 2020 Dirk Mueller <dmueller@suse.com>
- update to 2.0.3:
  * Fix: lib: use appropriate format specifier to print message iterator class
  * Fix: sink.text.pretty: check that port is connected before creating message iterator
  * Add initial Python bindings documentation
  * Fix: bt2: read properties on _DiscardedEventsMessage
  * tests: add tests for discarded events/packets creation
  * Fix: bt2: add precond. check, for stream class supporting discarded msgs with clock snapshot without clock class
  * Fix: flt-utils.muxer: reference leak in muxer_msg_iter_add_upstream_msg_iter error path
  * Fix: sink.text.details: goto error when failing to add input port
  * Fix: src.text.dmesg: add missing assignment of `status` on error path
  * Revert "bt2: _EventConst.__getitem__(): use a single temporary variable"
  * Fix: src.ctf.fs: initialize the other_entry variable
  * bt2: _EventConst.__getitem__(): use a single temporary variable
  * Fix: _EventConst.__getitem__(): check if event has a packet
  * doc: bt_field_class...get_mapping_labels...(): clarify RV's validity
  * doc/api/libbabeltrace2/style.css: make font weight of `.intertd` normal
  * common: cast arguments to character classification functions to unsigned char
  * flt.utils.muxer: initialize variable to silence -Wmaybe-uninitialized warning
  * Fix: configure.ac: silently accepting invalid Python configuration
  * Cleanup: configure.ac: remove redundant `AC_ARG_ENABLE` parameters
  * Fix: plugin-dev.h: Disable address sanitizer on pointer array section variables
  * Fix: cli: use BT_CLI_LOGE_APPEND_CAUSE instead of printf to print errors
  * tests: improve flt.utils.trimmer/test_trimming to test streams without packets
  * Fix: flt-utils.trimmer: accept streams without packet support
  * Fix: lib: don't assume that streams have packets in auto seek
  * Fix: correct typo in README
* Wed Feb 26 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Initial package.
